@@ -1,6 +1,6 @@
 package Bundle::Slash;
 
-$Bundle::Slash::VERSION = '1.0.11';
+$Bundle::Slash::VERSION = '1.12';
 
 1;
 
@@ -21,7 +21,9 @@ Bundle::CPAN		- File::Spec,Digest::MD5,Compress::Zlib,libnet,Archive::Tar,Data::
 
 Bundle::LWP		- URI,HTML::Parser,MIME::Base64
 
-Bundle::DBI		- Storable
+Getopt::Long
+
+DBI
 
 DBI::FAQ
 
@@ -47,11 +49,20 @@ Template		- Template Toolkit
 =head1 DESCRIPTION
 
 mod_perl must be installed by hand, because of the special configuration
-required for it.
+required for it.  DBIx::Password is special, and also installed by hand,
+but needed.
 
 If CPAN starts downloading "perl-5.6.0" or somesuch, ctrl-C it, exit
 the CPAN shell, and start it again.  The latest CPAN.pm version does not
 have this problem, but older ones do, and you may have an older one
 installed.
 
+Note that if you are not using MySQL, then you'll have some problems
+with this.  Just let it fail and install your DB library manually.
+Also note that Compress::Zlib and XML::Parser need extra libraries
+(see INSTALL for Slash, or the docs for the modules).
+
+We don't use Bundle::DBI because we don't need the Proxy stuff.  If you
+want the Proxy stuff, then install Bundle::DBI yourself.
+
 =cut
